@@ -70,6 +70,11 @@ Now, this file can be called from a SConstruct file like so::
 
     PyScons(targets, sources, "my_scons.py", options = "-j4")
 
+The string in the options keyword is NOT added to the command signature. Options that do affect the output
+should be added to the sig_options keyword, and these will be added to the signature::
+
+    PyScons(targets, sources, "my_scons.py", options = "-j4", sig_options = "--critical_opt")
+
 The temp file be generated if it is required to generate targets, but will be immediately deleted.
 This is useful for builders which generate large intermediate files which would should be deleted
 without triggering a rebuild. This can be better than passing a list to the Command function for a 
@@ -86,7 +91,7 @@ few special cases:
 
 Unfortunately, dependency tracking does not propagate up from the spawned scons. In this example, 
 "step1.py" and "step2.py" will not be tracked and changes to them will not trigger a rebuild. There
-is a trick around this, add the following two lines to "my_scons.py"
+is a trick around this, add the following two lines to "my_scons.py"::
 
     ### step1.py
     #DEPENDS step2.py
@@ -131,6 +136,8 @@ S. Joshua Swamidass (homepage_)
 .. _Scons: http://www.scons.org/
 """
 import os
+import os.path
+import shutil
 from SCons import Util
 from SCons.Action import CommandGeneratorAction
 from SCons.Scanner import Scanner
@@ -156,7 +163,7 @@ class PyScanner(MF):
             return MF.import_hook(self, name, caller, *arg, **karg) 
 
     def __call__(self, node, env, path):
-        if str(node).split('.')[-1] not in ['py', 'pyc', 'pyo', 'scons', 'pyscons']: return []
+        if str(node).split('.')[-1] not in ['py', 'pyc', 'pyo']: return []
         self.modules = {}; 
         self.name = str(node)
 
@@ -165,7 +172,7 @@ class PyScanner(MF):
 
         imports = [m.__file__ for m in self.modules.values() if m.__file__ != None]
 
-        if str(node).split('.')[-1] in ["py", "scons", "pyscons"]:
+        if str(node).split('.')[-1] in ["py"]:
             contents = open(str(node)).read()
             D = re.findall("#"+"##(.+)", contents) + re.findall("#" +"DEPENDS(.+)", contents, re.I)
             D = [f for f in chain(*(f.split() for f in D))]
@@ -173,6 +180,8 @@ class PyScanner(MF):
             for f in D:
                 f = os.path.join(d,f)
                 if os.path.exists(f): imports.append(f)
+        
+        imports = [i for i in imports if "/site-packages/" not in i]
 
         imports = list(os.path.abspath(m) for m in imports if self.path_filter(m))
         return imports
@@ -208,16 +217,16 @@ def _PyScript(env, target, source, command = "python $SOURCES",
     elif capture == None: pass
    
     command = [ env.subst(c, target=target, source=subst) for c in command ]
-    return env.Command(target, source, command, *args, **kwargs)  
+    return env.Command(target, source, command, *args, **kwargs) 
 
-def _PyScons(env, target, source, scons, options="-Q", clean = True, tempdir = None):
+def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = True, tempdir = None):
     target = ToList(target) 
     source = ToList(source) 
 
     args = " ".join(["in%g=%s" % (n+1, str(s)) for n,s in enumerate(source)])
     args += " " + " ".join(["out%g=%s" % (n+1, str(s)) for n,s in enumerate(target)])
 
-    sig = "scons -f%s %s" % (scons, args)
+    sig = "scons %s -f%s %s" % (sig_options, scons, args)
     if tempdir == None:
         m = hashlib.sha1()
         m.update(sig)
@@ -225,11 +234,11 @@ def _PyScons(env, target, source, scons, options="-Q", clean = True, tempdir = N
     else: TEMP = tempdir
 
     args += " " + "temp=" + TEMP    
-    cmd = "scons %s -f%s %s" % (options, scons, args)
-    clean = cmd + " --clean"
+    cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
+    cleancmd = cmd + " --clean"
     
     if env.GetOption("clean") and not clean: 
-        env.Execute(clean)
+        env.Execute(cleancmd)
         env.Execute(Delete(TEMP))
 
     if clean: 
@@ -282,5 +291,12 @@ def PySconsSetup(args=ARGUMENTS, tools=['default', PYTOOL()]):
     try: basename = args["temp"] 
     except: basename = None
 
+    ftargets = [t + ".force" for t in targets]
+    if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
+        for f,t in zip(ftargets,targets): 
+            print "Move(%s,%s)"%(f,t)
+            shutil.move(f,t)
+        env.Exit(0)
+
     return targets, sources, basename
 
